@@ -1,4 +1,4 @@
-# Copyright (c) 2022  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -67,7 +67,7 @@ def test_mock(parallel: bool, ignore: bool) -> None:
                 ["-p", "all"] if parallel else []
             ) + ["--", "-k", "chosen"]
             assert kwargs["env"]["TOX_SKIP_ENV"] == (
-                "^third|second|fou\\$rth\\.$" if ignore else "^second|fou\\$rth\\.$"
+                "^third|second|fourth$" if ignore else "^second|fourth$"
             )
             invoked.append("skipped")
         elif len(invoked) == 1:
@@ -76,7 +76,7 @@ def test_mock(parallel: bool, ignore: bool) -> None:
                 "-m",
                 "tox",
                 "-e",
-                "second,fou$rth.",
+                "second,fourth",
                 "--",
                 "-k",
                 "chosen",
@@ -94,7 +94,7 @@ def test_mock(parallel: bool, ignore: bool) -> None:
             with mock.patch.object(
                 sys,
                 "argv",
-                new=["tox_delay", "-e", "second,fou$rth."]
+                new=["tox_delay", "-e", "second,fourth"]
                 + (["-p", "all"] if parallel else [])
                 + (["-i", "third"] if ignore else [])
                 + ["--", "--", "-k", "chosen"],
